==> jc-1.4.0.tar.gz: soot/jimple/toolkits/scalar/pre/LatestComputation.h <==
// public class soot.jimple.toolkits.scalar.pre.LatestComputation

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f76371863dbe13d2 soot_jimple_toolkits_scalar_pre_LatestComputation

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_scalar_pre_LatestComputation_H_
#define _JC_soot_jimple_toolkits_scalar_pre_LatestComputation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;
struct _jc_soot_toolkits_scalar_BoundedFlowSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_refs	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$refs	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$nonrefs	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vmethods	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtable	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtype	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$method$_init$c65343d4361406a9(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$method$_init$2eab053fcc8af7f3(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$method$getFlowBefore$af587dd021ceb8ac(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$method_info$getFlowBefore$af587dd021ceb8ac;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vmethods {
	struct _jc_java_lang_Object$object	*(*getFlowBefore$af587dd021ceb8ac)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vmethods	soot_jimple_toolkits_scalar_pre_LatestComputation;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_refs {
	struct _jc_object	*unitToLatest;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$refs {
    _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_refs	soot_jimple_toolkits_scalar_pre_LatestComputation;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_nonrefs	soot_jimple_toolkits_scalar_pre_LatestComputation;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object {
	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtype _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_pre_LatestComputation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_pre_LatestComputation_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/scalar/pre/LatestComputation.h <==
// public class soot.jimple.toolkits.scalar.pre.LatestComputation

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f76371863dbe13d2 soot_jimple_toolkits_scalar_pre_LatestComputation

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_scalar_pre_LatestComputation_H_
#define _JC_soot_jimple_toolkits_scalar_pre_LatestComputation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;
struct _jc_soot_toolkits_scalar_BoundedFlowSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_refs	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$refs	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$nonrefs	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vmethods	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtable	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtype	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$method$_init$c65343d4361406a9(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$method$_init$2eab053fcc8af7f3(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$method$getFlowBefore$af587dd021ceb8ac(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$method_info$getFlowBefore$af587dd021ceb8ac;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vmethods {
	struct _jc_java_lang_Object$object	*(*getFlowBefore$af587dd021ceb8ac)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vmethods	soot_jimple_toolkits_scalar_pre_LatestComputation;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_refs {
	struct _jc_object	*unitToLatest;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$refs {
    _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_refs	soot_jimple_toolkits_scalar_pre_LatestComputation;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$sub_nonrefs	soot_jimple_toolkits_scalar_pre_LatestComputation;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$object {
	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_pre_LatestComputation$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$vtype _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_pre_LatestComputation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_pre_LatestComputation$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_pre_LatestComputation_H_ */
